

| alias | url | supports_name | Description |
|---|---|---|---|
| namespaces | api/v1/namespaces  | True| All namespaces |
| nodes | api/v1/nodes  | True | All nodes |

https://kubernetes.io/docs/reference/kubernetes-api/workload-resources/pod-v1/

| nodes | api/v1/nodes  | False | All nodes |


